@@ -1,18 +1,23 @@
 context("Climate Normals")
 
 test_that("normals_url() correctly creates urls", {
+  if(on_CRAN()) mockery::stub(normals_url, "check_url", "")
+
   expect_equal(
     normals_url(prov = "MB", climate_id = c("5010480", "5010480"),
                 normals_years = "1981-2010"),
     paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/1981-2010/",
            "MB/climate_normals_MB_", c("5010480", "5010480"), "_1981-2010.csv"))
 
-  expect_error(normals_url(prov = "MB", climate_id = c("5010480", "5010480"),
-                           normals_years = "1971-2000"), "Climate normals are not")
-
   expect_silent(normals_url(prov = "MB", climate_id = "5010480",
                             normals_years = "1981-2010"))
 
+  skip_on_cran()
+  expect_error(normals_url(prov = "MB", climate_id = c("5010480", "5010480"),
+                           normals_years = "1971-2000"),
+               "Failed to access climate normals for years 1971-2000",
+               class = "http_404")
+
   bkup <- getOption("weathercan.urls.normals")
   options(weathercan.urls.normals = "https://httpstat.us/404")
   expect_error(normals_url(prov = "MB", climate_id = "5010480",
@@ -23,6 +28,7 @@ test_that("normals_url() correctly creates urls", {
 })
 
 test_that("normals_raw() download normals as character", {
+  skip_on_cran()
   url <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
                 "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv")
   expect_silent(normals_raw(url)) %>%
@@ -34,9 +40,13 @@ test_that("normals_raw() download normals as character", {
 })
 
 test_that("normals_extract() cleans up raw data", {
-  n <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
-              "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv") %>%
+  if(on_CRAN()) {
+    n <- tests$normals_raw_01
+  } else {
+    n <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
+                "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv") %>%
     normals_raw()
+  }
   expect_silent(n1 <- normals_extract(n)) %>%
     expect_is("character")
   expect_lt(length(n1), length(n))
@@ -44,10 +54,15 @@ test_that("normals_extract() cleans up raw data", {
 })
 
 test_that("data_extract() / frost_extract() extract data", {
-  n <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
-         "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv") %>%
-    normals_raw() %>%
-    normals_extract()
+  if(on_CRAN()) {
+    n <- tests$normals_raw_01
+  } else {
+    n <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
+                "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv") %>%
+    normals_raw()
+  }
+  n <- normals_extract(n)
+
   expect_silent(data_extract(n, climate_id = "5010480")) %>%
     expect_is("data.frame")
   expect_silent(frost_extract(n, climate_id = "5010480")) %>%
@@ -55,10 +70,14 @@ test_that("data_extract() / frost_extract() extract data", {
 })
 
 test_that("normals_format()/frost_format() format data to correct class", {
-  n <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
-              "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv") %>%
-    normals_raw() %>%
-    normals_extract()
+  if(on_CRAN()) {
+    n <- tests$normals_raw_01
+  } else {
+    n <- paste0("https://dd.meteo.gc.ca/climate/observations/normals/csv/",
+                "1981-2010/MB/climate_normals_MB_5010480_1981-2010.csv") %>%
+      normals_raw()
+  }
+  n <- normals_extract(n)
 
   f <- frost_extract(n, climate_id = "5010480")
   n <- data_extract(n, climate_id = "5010480")
@@ -77,6 +96,9 @@ test_that("normals_format()/frost_format() format data to correct class", {
 })
 
 test_that("normals_dl() downloads normals/frost dates as tibble", {
+
+  if(on_CRAN()) mockery::stub(normals_dl, "normals_raw", tests$normals_raw_01)
+
   expect_silent(normals_dl(climate_id = "5010480")) %>%
     expect_is("tbl_df")
 
